﻿using Hotline.Share.Enums;
using Hotline.Share.Enums.Order;
using Hotline.Share.Enums.Snapshot;
using Hotline.Share.Requests;
using System.ComponentModel.DataAnnotations;
using XF.Utility.EnumExtensions;

namespace Hotline.Share.Dtos.Snapshot;

public class OrderInDto : QueryFixedDto
{
    /// <summary>
    /// 关键字
    /// </summary>
    public string? KeyWords { get; set; }

    /// <summary>
    /// 工单状态;
    /// 0: 全部;
    /// 1: 未回复;
    /// 2: 已回复;
    /// 3: 已评价;
    /// </summary>
    public EOrderQueryStatus Status { get; set; }
}

public class OrderDetailOutDto : OrderOutDto
{
}

public class OrderOutDto
{
    public string Id { get; set; }

    /// <summary>
    /// 工单编号
    /// </summary>
    public string OrderNo { get; set; }

    /// <summary>
    /// 标题
    /// </summary>
    public string Title { get; set; }

    /// <summary>
    /// 工单状态
    /// </summary>
    public EOrderStatus Status { get; set; }

    /// <summary>
    /// 行业名字
    /// </summary>
    public string IndustryName { get; set; }

    /// <summary>
    /// 工单状态描述
    /// </summary>
    public string StatusText
    {
        get
        {
            if (Status == EOrderStatus.Published || Status == EOrderStatus.Filed)
            {
                return "办理完成";
            }
            return Status.GetDescription();
        }
    }

    /// <summary>
    /// 时间
    /// </summary>
    public DateTime CreationTime { get; set; }

    /// <summary>
    /// 时间文本
    /// </summary>
    public string CreationTimeText => this.CreationTime.ToString("yyyy-MM-dd hh:mm:ss");

    /// <summary>
    /// 区域
    /// </summary>
    public string Area { get; set; }
}
public class OrderDto
{
}

public class AddSnapshotOrderOutDto
{
    public string Id { get; set; }
    public string No { get; set; }
    public string Password { get; set; }
}

public class AddSnapshotOrderInDto : Position
{
    /// <summary>
    /// 行业Id
    /// </summary>
    [Required(ErrorMessage = "行业Id不能为空")]
    public string IndustryId { get; set; }

    /// <summary>
    /// 作业类型
    /// </summary>
    public string? JobType { get; set; }

    /// <summary>
    /// 经营单位类别
    /// </summary>
    public string? BusinessUnitType { get; set; }

    /// <summary>
    /// 作业场所
    /// </summary>
    public string? Workplace { get; set; }

    /// <summary>
    /// 场所名称(多个场所使用 - 连接)
    /// </summary>
    public string? WorkplaceName { get; set; }

    /// <summary>
    /// 作业时间
    /// </summary>
    public DateTime? StartWorkTime { get; set; }

    /// <summary>
    /// 作业结束时间
    /// </summary>
    public DateTime? EndWorkTime { get; set; }

    /// <summary>
    /// 姓名
    /// </summary>
    [Required(ErrorMessage = "姓名不能为空")]
    public string Name { get; set; }

    /// <summary>
    /// 联系方式
    /// </summary>
    [Required(ErrorMessage = "联系方式不能为空")]
    public string PhoneNumber { get; set; }

    /// <summary>
    /// 是否保密
    /// </summary>
    public bool? IsSecret { get; set; }

    /// <summary>
    /// 附件信息
    /// </summary>
    public IList<SnapshotFileInDto> Files { get; set; }

    /// <summary>
    /// 事件描述
    /// </summary>
    public string? Description { get; set; }

    public string GetContent(EIndustryType industryType)
    {
        if (industryType == EIndustryType.Declare)
        {
            return $"经营单位类别: {this.BusinessUnitType}\r\n" + // 个人
                    $"作业场所:{this.Workplace}\r\n" + // 化工、民爆物品生产经营企业
                    $"场所名称:{this.WorkplaceName}\r\n" + // 多业态混合经营场所 - 存储多种功能的劳动密集型企业
                    $"作业区域: {this.County + this.Town}\r\n" + // 自流井区舒坪街道
                    $"作业类型: {this.JobType}\r\n" + // 电焊
                    $"作业时间:{this.StartWorkTime.Value.ToString("yyyy-MM-dd hh:mm")}~{this.EndWorkTime.Value.ToString("yyyy-MM-dd hh:mm")}\r\n" +
                    $"作业地点: {this.Town}({this.County})（{this.Street}）"; // 舒平(自流井区)（油库）"
        }
        return $"{Description}";
    }

    public string GetTitle(EIndustryType industryType, string acceptType)
    {
        if (industryType == EIndustryType.Declare)
        {
            return $"【随手拍】关于{Town}({County})的申报";
        }

        return $"【随手拍】关于{Town}({County})的" + acceptType;
    }
}


/// <summary>
/// 红包审核入参
/// </summary>
/// <param name="No"></param>
/// <param name="Title"></param>
/// <param name="FromPhone">来电人电话</param>
/// <param name="BeginCreationTime">受理开始时间</param>
/// <param name="EndCreationTime">受理结束时间</param>
/// <param name="IsDeal">是否办理</param>
/// <param name="IsTruth">网格员是否属实</param>
/// <param name="IsTruthDepartment">部门是否属实</param>
/// <param name="BeginAuditTime">审批开始时间</param>
/// <param name="EndAuditTime">审批结束时间</param>
/// <param name="BeginFiledTime">办结开始时间</param>
/// <param name="EndFiledTime">办结结束时间</param>
/// <param name="IsIssued">是否发放红包</param>
/// <param name="IndustryId">行业Id</param>
/// <param name="ConfigAmount">配置金额</param>
/// <param name="AcutalAmount">实际发放金额</param>
/// <param name="ApprovedAmount">审批金额</param>
/// <param name="IsDanger">是否安全生成</param>
/// <param name="Status">审核状态</param>
public record SnapshotOrderAuditItemsInDto(string? No, string? Title,
    string? FromPhone,
    DateTime? BeginCreationTime,
    DateTime? EndCreationTime,
    bool? IsDeal,
    bool? IsTruth,
    bool? IsTruthDepartment,
    DateTime? BeginAuditTime,
    DateTime? EndAuditTime,
    DateTime? BeginFiledTime,
    DateTime? EndFiledTime,
    bool? IsIssued,
    string? IndustryId,
    double? ConfigAmount,
    double? AcutalAmount,
    double? ApprovedAmount,
    bool? IsDanger,
    ERedPackAuditStatus? Status) : PagedRequest;

public class SnapshotOrderAuditItemsOutDto
{
    /// <summary>
    /// 红包审核Id
    /// </summary>
    public string Id { get; set; }

    /// <summary>
    /// 红包审核Id
    /// </summary>
    public string RedPackAuditId { get; set; }

    /// <summary>
    /// OrderId
    /// </summary>
    public string OrderId { get; set; }

    /// <summary>
    /// No
    /// </summary>
    public string No { get; set; }

    /// <summary>
    /// 标题
    /// </summary>
    public string Title { get; set; }

    /// <summary>
    /// 行业
    /// </summary>
    public string IndustryName { get; set; }

    /// <summary>
    /// 行业Id
    /// </summary>
    public string IndustryId { get; set; }

    /// <summary>
    /// 来源渠道（电话、网站、APP等）
    /// </summary>
    public string? SourceChannel { get; set; }

    /// <summary>
    /// 来源渠道代码
    /// </summary>
    public string? SourceChannelCode { get; set; }

    /// <summary>
    /// 工单状态
    /// </summary>
    public EOrderStatus Status { get; set; }

    /// <summary>
    /// 状态
    /// </summary>
    public string StatusTxt => Status.GetDescription();

    /// <summary>
    /// 线索分类
    /// </summary>
    public string IndustryCase { get; set; }

    /// <summary>
    /// 线索分类
    /// </summary>
    public string IndustryCaseId { get; set; }

    /// <summary>
    /// 标记为安全生产
    /// </summary>
    public bool? IsDanger { get; set; }

    /// <summary>
    /// 来电号码
    /// </summary>
    public string? FromPhone { get; set; }

    /// <summary>
    /// 来电/信人姓名
    /// </summary>
    public string? FromName { get; set; }

    /// <summary>
    /// 审批时间
    /// </summary>
    public DateTime? AuditTime { get; set; }

    /// <summary>
    /// 审批金额
    /// </summary>
    public double? ApprovedAmount { get; set; }

    /// <summary>
    /// 实发金额
    /// </summary>
    public double? AcutalAmount { get; set; }

    /// <summary>
    /// 补充发放金额
    /// </summary>
    public double? ReplenishAmount { get; set; }

    /// <summary>
    /// 市民奖励发放结果
    /// 是否已发放
    /// </summary>
    public bool? IsIssued { get; set; }

    /// <summary>
    /// 市民奖励
    /// </summary>
    public string CitizenAward { get; set; }

    /// <summary>
    /// 市民奖励发放备注
    /// </summary>
    public string RecordRemark { get; set; }

    /// <summary>
    /// 区域
    /// </summary>
    public string County { get; set; }

    /// <summary>
    /// 部门是否整改完成;
    /// 是否整改
    /// </summary>
    public bool IsRectify { get; set; }

    /// <summary>
    /// 网格员是否办理
    /// </summary>
    public bool? IsDeal { get; set; }

    /// <summary>
    /// 网格E通编号
    /// </summary>
    public string? NetworkENumber { get; set; }

    /// <summary>
    /// 网格员是否属实
    /// </summary>
    public bool? IsTruth { get; set; }

    /// <summary>
    /// 部门是否属实
    /// </summary>
    public bool? IsTruthDepartment { get; set; }

    /// <summary>
    /// 是否重复
    /// </summary>
    public bool? IsRepetition { get; set; }

    /// <summary>
    /// 受理时间
    /// </summary>
    public DateTime CreationTime { get; set; }

    /// <summary>
    /// 一级部门code
    /// </summary>
    public string? OrgLevelOneCode { get; set; }

    /// <summary>
    /// 一级部门名称
    /// </summary>
    public string? OrgLevelOneName { get; set; }

    /// <summary>
    /// 审批人
    /// </summary>
    public string? AuditId { get; set; }

    /// <summary>
    /// 审批人
    /// </summary>
    public string? AuditName { get; set; }

    /// <summary>
    /// 审批部门
    /// </summary>
    public string? AuditOrgId { get; set; }

    /// <summary>
    /// 审批部门名称
    /// </summary>
    public string? AuditOrgName { get; set; }

    /// <summary>
    /// 审批意见
    /// </summary>
    public string? AuditRemark { get; set; }

    /// <summary>
    /// 银行卡号
    /// </summary>
    public string? BankCardNo { get; set; }

    /// <summary>
    /// 开户行
    /// </summary>
    public string? OpenBank { get; set; }

    /// <summary>
    /// 红包审核状态
    /// </summary>
    public ERedPackAuditStatus AuditStatus { get; set; }

    /// <summary>
    /// 红包审核状态
    /// </summary>
    public string AuditStatusTxt => AuditStatus.GetDescription();
}

public class GetRedPackAuditSMSTemplateOutDto
{
    /// <summary>
    /// Id
    /// </summary>
    public string Id { get; set; }

    /// <summary>
    /// 内容
    /// </summary>
    public string Content { get; set; }
}

public class GetRedPackAuditSMSTemplateInDto
{
    public GetRedPackAuditSMSTemplateInDto()
    {
        
    }

    public GetRedPackAuditSMSTemplateInDto(string id, ERedPackAuditStatus status)
    {
        OrderId = id;
        Status = status;
    }

    /// <summary>
    /// OrderId
    /// </summary>
    public string OrderId { get; set; }

    /// <summary>
    /// 状态
    /// </summary>
    public ERedPackAuditStatus Status { get; set; }
}

public class SnapshotOrderAuditDetailOutDto
{
    /// <summary>
    /// 工单信息
    /// </summary>
    public SnapshotOrderAuditOrderDetailOutDto Order { get; set; }

    /// <summary>
    /// 市民红包金额
    /// </summary>
    public double Amount { get; set; }

    /// <summary>
    /// 红包发放
    /// </summary>
    public string RedPackTxt { get; set; }

    /// <summary>
    /// 审核状态
    /// </summary>
    public IEnumerable<KeyValuePair<int, string>> AuditComBox { get; set; }
}

public class SnapshotOrderAuditOrderDetailOutDto
{
    /// <summary>
    /// 受理人id
    /// </summary>
    public string? AcceptorId { get; set; }

    /// <summary>
    /// 受理人名称
    /// </summary>
    public string? AcceptorName { get; set; }

    /// <summary>
    /// 受理时间
    /// </summary>
    public DateTime CreationTime { get; set; }

    /// <summary>
    /// No
    /// </summary>
    public string No { get; set; }

    /// <summary>
    /// 所属区域
    /// </summary>
    public string County { get; set; }

    /// <summary>
    /// 来源方式
    /// </summary>
    public string SourceChannel { get; set; }

    /// <summary>
    /// 来源渠道代码
    /// </summary>
    public string? SourceChannelCode { get; set; }

    /// <summary>
    /// 受理类型
    /// </summary>
    public string? AcceptType { get; set; }

    /// <summary>
    /// 受理类型代码
    /// </summary>
    public string? AcceptTypeCode { get; set; }

    /// <summary>
    /// 热点分类类目名称
    /// </summary>
    public string? HotspotSpliceName { get; set; }

    /// <summary>
    /// 来电人
    /// </summary>
    public string FromPhone { get; set; }

    /// <summary>
    /// 来电/信人姓名
    /// </summary>
    public string? FromName { get; set; }


    private bool _isSecret;
    /// <summary>
    /// 是否保密
    /// </summary>
    public bool IsSecret
    {
        get
        {
            if (_isSecret == true)
            {
                FullAddress = "*";
                WorkUnit = "*";
                LicenceNo = "*";
                FromName = "*";
                FromPhone = "*";
            }
            return _isSecret;
        }
        set { _isSecret = value; }
    }

    /// <summary>
    /// 性别
    /// </summary>
    public string FromGenderTxt
    {
        get
        {
            if (_isSecret == true)
                return "*";
            return FromGender.GetDescription();
        }
    }
    /// <summary>
    /// 来电/信人性别
    /// </summary>
    public EGender FromGender { get; set; }

    /// <summary>
    /// 地址
    /// </summary>
    public string FullAddress { get; set; }

    /// <summary>
    /// 工作单位
    /// </summary>
    public string WorkUnit { get; set; }

    /// <summary>
    /// 证件号码
    /// </summary>
    public string LicenceNo { get; set; }
}

public class UpdateRedPackAuditInDto
{
    /// <summary>
    /// 审核Id
    /// </summary>
    public string RedPackAuditId { get; set; }

    /// <summary>
    /// 审核状态
    /// </summary>
    public ERedPackAuditStatus Status { get; set; }

    /// <summary>
    /// 审核意见
    /// </summary>
    public string Opinion { get; set; }

    /// <summary>
    /// 短信模板Id
    /// </summary>
    [Required]
    public string SMSTemplateId { get; set; }

    /// <summary>
    /// 是否发送短信
    /// </summary>
    public bool IsSendSms { get; set; }
}

public class GetAuditBackBaseDataOutDto
{
    /// <summary>
    /// 流程Id
    /// </summary>
    public string WorkflowId { get; set; }

    /// <summary>
    /// 特提次数
    /// </summary>
    public int SpecialNum { get; set; }

    /// <summary>
    /// 实际办理节点code（会签状态此字段保存最外层会签发起节点code）
    /// </summary>
    public string ActualHandleStepCode { get; set; }

    /// <summary>
    /// 实际办理节点名称（会签状态此字段保存最外层会签发起节点名称）
    /// </summary>
    public string ActualHandleStepName { get; set; }

    /// <summary>
    /// 受理类型代码
    /// </summary>
    public string AcceptTypeCode { get; set; }
}
